################################################################################
Using Bolt
################################################################################

You want to try Bolt? That's great! You can start by installing Bolt and
creating your first `boltfile.py`. You can find how to do it in the 
:doc:`Getting Started <using/getting_started>` guide. Then, you can check the 
other topics in this section to learn more about Bolt, its features, and how to 
create your own tasks.


..  toctree::
    :maxdepth: 1

    using/getting_started
    using/disecting_boltfile
    using/provided_tasks
    using/custom_tasks
